import { EndpointV2, Logger } from "@smithy/types";
import { EndpointParameters } from "./EndpointParameters";
export declare const defaultEndpointResolver: (
  endpointParams: EndpointParameters,
  context?: {
    logger?: Logger;
  }
) => EndpointV2;
