import { PaginationConfiguration } from "@smithy/types";
import { CognitoIdentityClient } from "../CognitoIdentityClient";
export interface CognitoIdentityPaginationConfiguration
  extends PaginationConfiguration {
  client: CognitoIdentityClient;
}
